#!/bin/sh

#------------ exit value  ------------
#  0
#  1	Error executing command


#on stdout warning messages
#on stderr YUO can find system/catalog error messages

#------- get the parametres from the caller -------
MAIN_DIR="$1"
INSTALL_DIR="$2"
MAEUSER="$3"
TWS_CPUTYPE="$4"
TWS_MASTER="$5"
TWS_THISCPU="$6"
TWS_PORT="$7"
CREATELINKS_OPT="$8"
VERBOSE="$9"

ACTIONTOOLS_DIR=$MAIN_DIR/ACTIONTOOLS
STATUSDIR=$INSTALL_DIR/_uninstall/ACTIONTOOLS

# List of TWS files
tws_files_list=$MAIN_DIR/ACTIONTOOLS/filelist_bck821

OS=`uname -s`;export OS
case $OS in
   AIX)
     INST_INTERP="AIX"; export INST_INTERP
   ;;
   HP-UX)
     INST_INTERP="HP"; export INST_INTERP
   ;;
   Linux)
     case `uname -m` in
     *86*)
       INST_INTERP="LINUX_I386"; export INST_INTERP
       ;;
     *390*)
       INST_INTERP="LINUX_S390"; export INST_INTERP
       ;;
     esac
   ;;
   SunOS)
     INST_INTERP="SOLARIS"; export INST_INTERP
   ;;
   *) 
     INST_INTERP="LINUX_I386"; export INST_INTERP
   ;;
esac

if [ "$VERBOSE" != "-verbose" ] 
then
  VERBOSE=""
fi

echo "twsConfigActionInProgress...."
echo "MAIN_DIR=$MAIN_DIR"
echo "INSTALL_DIR=$INSTALL_DIR"
echo "MAEUSER=$MAEUSER"
# Possible values: SA FTA MDM BKM
echo "TWS_CPUTYPE=$TWS_CPUTYPE"
echo "TWS_MASTER=$TWS_MASTER"
echo "TWS_THISCPU=$TWS_THISCPU"
echo "TWS_PORT=$TWS_PORT"
echo "INST_INTERP=$INST_INTERP"
echo "ACTIONTOOLS_DIR=$ACTIONTOOLS_DIR"
echo "CREATELINKS_OPT=$CREATELINKS_OPT"

echo "STATUS FILES"
echo "`ls -la $STATUSDIR/*.historyFile`"

if [ -z "$UNISON_COMPONENT_FILE" ]
then
  UNISON_COMPONENT_FILE="/usr/unison/components"; export UNISON_COMPONENT_FILE
fi
echo "UNISON_COMPONENT_FILE=$UNISON_COMPONENT_FILE"

#
# execute_command is used to execute a command and capture errors.
#
# Arguments:
#	<command> args
execute_command()
{
 $@
 exitValue=$?
 if [ $exitValue -ne 0 ]
 then
   if [ "$VERBOSE" != "-verbose" ]
   then
     echo "The following command failed: $@." >&2
   else
     echo "$@." >&2
   fi
   exit $exitValue
 fi
}


CreateLinks()
{
  arg1=$1
  arg2=$2
  EXECPATH=/usr/bin

# if [ -f $EXECPATH/$arg2 -o $IS_SYMLINK $EXECPATH/$arg2 ]
# then
#    "WARNING removing $EXECPATH/$arg2`"
#    rm $EXECPATH/$arg2
# fi

 # echo "link da creare $INSTALL_DIR/bin/$arg1 --> $EXECPATH/$arg2" >&1
  if [ ! -f $EXECPATH/$arg2 ]
  then
    if ln -f -s  $INSTALL_DIR/bin/$arg1 $EXECPATH/$arg2 2>/dev/null >&1
    then
      echo #"link creato $INSTALL_DIR/bin/$arg1 --> $EXECPATH/$arg2" >&1
    else
      echo "WARNING : Error creating softlink  $INSTALL_DIR/bin/$arg1 --> $EXECPATH/$arg2" >&1
    fi
  else
#    echo  "WARNING : Path name $EXECPATH/$arg2 does not exist" >&1
    echo
  fi
}



#
#
# Start of Main Script Logic.
#


#
CMD_GROUPS=/usr/bin/groups
if [ ! -x /usr/bin/groups ]
then
	if [ -x /usr/ucb/groups ]
	then
		CMD_GROUPS=/usr/ucb/groups
	fi
fi

#
#At present we are not aware of any standard way of finding out primary
#group of a user. If we can, following case statement should be replaced.
#
case $OS in
   HP-UX|AIX|OSF1|IRIX64)
            MAEGROUP=`id -gn $MAEUSER`
          ;;
   DYNIX/ptx)
	    MAEGROUP=`getgroups $MAEUSER`
          ;;
   SunOS)
			if [ "`uname -r`" -lt 5.0 ]
			 then
              MAEGROUP=`$CMD_GROUPS $MAEUSER | awk -F: '{print $2}' | cut -d" " -f2`
			 else
              MAEGROUP=`$CMD_GROUPS $MAEUSER | cut -d" " -f 1-1`
			fi
	  ;;
   Linux)
              MAEGROUP=`$CMD_GROUPS $MAEUSER | awk -F: '{print $2}' | cut -d" " -f2`
          ;;
       *)
              MAEGROUP=`$CMD_GROUPS $MAEUSER | cut -d" " -f 1-1`
          ;;
esac

export MAEGROUP



# INSTALL: AUTOTRACE If the product is autotrace enabled, we need to put suitable runtime libraries to /usr/lib
# before executing any Maestro operation. We use sym links

   TIVOLI_COM_DIR=/usr/Tivoli
   TKG_RUNTIME_LIBPATH=$TIVOLI_COM_DIR/TWS/TKG/3.1.5/lib
   LIBATRC_FILENAME=libatrc.a
   case $OS in
     AIX)
        LIBATRC_FILENAME=libatrc.a
     ;;
     SunOS)
        LIBATRC_FILENAME=libatrc.so
     ;;
     Linux)
        LIBATRC_FILENAME=libatrc.so
     ;;
     HP-UX)
        LIBATRC_FILENAME=libatrc.sl
     ;;
   esac

if [ -d $INSTALL_DIR/trace ]
then
   if [ ! -f $TKG_RUNTIME_LIBPATH/$LIBATRC_FILENAME ]
   then
     mkdir -p $TKG_RUNTIME_LIBPATH 2>/dev/null
     chmod -R u+w $TIVOLI_COM_DIR 2>/dev/null

     echo "Info: Copying TKG libraries under $TKG_RUNTIME_LIBPATH directory..."   
     execute_command cp -f $INSTALL_DIR/trace/$LIBATRC_FILENAME $TKG_RUNTIME_LIBPATH 2>/dev/null

     echo "Info: changing access grant to $TIVOLI_COM_DIR directory"
     ### APAR IY48409
     #   Absolute permissions: not depending from the user umask
     chmod -R ugo+rx $TIVOLI_COM_DIR 2>/dev/null
     chmod -R 755 $TIVOLI_COM_DIR 2>/dev/null

   else
     echo "Info: $TKG_RUNTIME_LIBPATH/$LIBATRC_FILENAME already exist..."   
   fi
fi

# Creating ftbox dir
if [ ! -d $INSTALL_DIR/ftbox ]
then
  mkdir $INSTALL_DIR/ftbox
  execute_command chown $MAEUSER $INSTALL_DIR/ftbox
  execute_command chgrp -R $MAEGROUP $INSTALL_DIR/ftbox
fi


# Set permission on twsRemove.sh
if [ -f $INSTALL_DIR/twsRemove.sh ]
then
	execute_command chown $MAEUSER $INSTALL_DIR/twsRemove.sh
	execute_command chgrp $MAEGROUP $INSTALL_DIR/twsRemove.sh
	execute_command chmod 755 $INSTALL_DIR/twsRemove.sh
fi


# Set permission on twsRestore.sh
if [ -f $INSTALL_DIR/twsRestore.sh ]
then
	execute_command chown $MAEUSER $INSTALL_DIR/twsRestore.sh
	execute_command chgrp $MAEGROUP $INSTALL_DIR/twsRestore.sh
	execute_command chmod 755 $INSTALL_DIR/twsRestore.sh
fi

# INSTALL: set file permissions

execute_command chown $MAEUSER $INSTALL_DIR
echo "Info: $MAEUSER user ownership assigned to $INSTALL_DIR directory"

execute_command chgrp $MAEGROUP $INSTALL_DIR
echo "Info: $MAEGROUP group ownership assigned to $INSTALL_DIR directory"




echo "Change GROUP access grant to $INSTALL_DIR files"

# Group for TWSHOME dir files
if [ -f $INSTALL_DIR/Jnextday ]
then
	execute_command chgrp $MAEGROUP $INSTALL_DIR/Jnextday
fi
if [ -f $INSTALL_DIR/jobmanrc ]
then
	execute_command chgrp $MAEGROUP $INSTALL_DIR/jobmanrc
fi
if [ -f $INSTALL_DIR/Sfinal ]
then
	execute_command chgrp $MAEGROUP $INSTALL_DIR/Sfinal
fi
if [ -f $INSTALL_DIR/StartUp ]
then
	execute_command chgrp $MAEGROUP $INSTALL_DIR/StartUp
fi
if [ -f $INSTALL_DIR/tws_env.csh ]
then
	execute_command chgrp $MAEGROUP $INSTALL_DIR/tws_env.csh
fi
if [ -f $INSTALL_DIR/tws_env.sh ]
then
	execute_command chgrp $MAEGROUP $INSTALL_DIR/tws_env.sh
fi

# Group for TWSHOME/bin dir files
tws_files_list="`cat ${tws_files_list}`"

for var in $tws_files_list; do
  PATH_OF_FILE="`dirname $var`"
  if [ "$PATH_OF_FILE" = "bin" ]
  then
    if [ -f $INSTALL_DIR/$var ]
    then
      execute_command chgrp $MAEGROUP $INSTALL_DIR/$var
    fi
  fi
done


#IY35151
# After the GA installation NUMEROUS DIRECTORY PERMISSIONS ARE WORLD-WRITABLE
#
if [ -d $INSTALL_DIR/atjobs ]
then
  execute_command chgrp -R $MAEGROUP $INSTALL_DIR/atjobs
  #execute_command chmod -R o-w $INSTALL_DIR/atjobs
fi

if [ -d $INSTALL_DIR/methods ]
then
  execute_command chgrp -R $MAEGROUP $INSTALL_DIR/methods
  #execute_command chmod -R o-w $INSTALL_DIR/methods
fi

if [ -d $INSTALL_DIR/network ]
then
  execute_command chgrp -R $MAEGROUP $INSTALL_DIR/network
  #execute_command chmod -R o-w $INSTALL_DIR/network
fi

if [ -d $INSTALL_DIR/pids ]
then
  execute_command chgrp -R $MAEGROUP $INSTALL_DIR/pids
  #execute_command chmod -R o-w $INSTALL_DIR/pids
fi

if [ -d $INSTALL_DIR/pobox ]
then
  execute_command chgrp -R $MAEGROUP $INSTALL_DIR/pobox
  #execute_command chmod -R o-w $INSTALL_DIR/pobox
fi

if [ -d $INSTALL_DIR/schedlog ]
then
  execute_command chgrp -R $MAEGROUP $INSTALL_DIR/schedlog
  #execute_command chmod -R o-w $INSTALL_DIR/schedlog
fi

if [ -d $INSTALL_DIR/stdlist ]
then
  execute_command chgrp -R $MAEGROUP $INSTALL_DIR/stdlist
  #execute_command chmod -R o-w $INSTALL_DIR/stdlist
fi

if [ -d $INSTALL_DIR/tmp ]
then
  execute_command chgrp -R $MAEGROUP $INSTALL_DIR/tmp
  #execute_command chmod -R o-w $INSTALL_DIR/tmp
fi

if [ -d $INSTALL_DIR/trace ]
then
  execute_command chgrp -R $MAEGROUP $INSTALL_DIR/trace
  #execute_command chmod -R o-w $INSTALL_DIR/trace
fi

if [ -d $INSTALL_DIR/OV ]
then
  execute_command chgrp -R $MAEGROUP $INSTALL_DIR/OV
  execute_command chmod -R o-w $INSTALL_DIR/OV
fi

if [ -d $INSTALL_DIR/unsupported ]
then
  execute_command chgrp -R $MAEGROUP $INSTALL_DIR/unsupported
  execute_command chmod -R o-w $INSTALL_DIR/unsupported
fi

if [ -d $INSTALL_DIR/catalog ]
then
  execute_command chgrp -R $MAEGROUP $INSTALL_DIR/catalog
  execute_command chmod -R go-w $INSTALL_DIR/catalog
fi

if [ -d $INSTALL_DIR/codeset ]
then
  execute_command chgrp -R $MAEGROUP $INSTALL_DIR/codeset
  execute_command chmod -R go-w $INSTALL_DIR/codeset
fi

if [ -d $INSTALL_DIR/config ]
then
  execute_command chgrp -R $MAEGROUP $INSTALL_DIR/config
  execute_command chmod -R go-w $INSTALL_DIR/config
fi

if [ -d $INSTALL_DIR/demo ]
then
  execute_command chgrp -R $MAEGROUP $INSTALL_DIR/demo
  execute_command chmod -R go-w $INSTALL_DIR/demo
fi

if [ -d $INSTALL_DIR/man ]
then
  execute_command chgrp -R $MAEGROUP $INSTALL_DIR/man
  execute_command chmod -R go-w $INSTALL_DIR/man
fi

if [ -d $INSTALL_DIR/zoneinfo ]
then
  execute_command chgrp -R $MAEGROUP $INSTALL_DIR/zoneinfo
  execute_command chmod -R go-w $INSTALL_DIR/zoneinfo
fi

if [ -d $INSTALL_DIR/audit ]
then
  execute_command chgrp -R $MAEGROUP $INSTALL_DIR/audit
  execute_command chmod -R go-w $INSTALL_DIR/audit
fi

if [ -d $INSTALL_DIR/Tbsm ]
then
  execute_command chgrp -R $MAEGROUP $INSTALL_DIR/Tbsm
  execute_command chmod -R go-w $INSTALL_DIR/Tbsm
fi

if [ -d $INSTALL_DIR/version ]
then
  execute_command chgrp -R $MAEGROUP $INSTALL_DIR/version
  execute_command chmod -R go-w $INSTALL_DIR/version
fi

if [ -d $INSTALL_DIR/mozart ]
then
  execute_command chgrp -R $MAEGROUP $INSTALL_DIR/mozart
  execute_command chmod -R go-w $INSTALL_DIR/mozart
fi

if [ -d $INSTALL_DIR/ftbox ]
then
  execute_command chgrp -R $MAEGROUP $INSTALL_DIR/ftbox
  execute_command chmod -R go-w $INSTALL_DIR/ftbox
fi

if [ -f $INSTALL_DIR/TWSCCLog.properties ]
then
  execute_command chgrp $MAEGROUP $INSTALL_DIR/TWSCCLog.properties
  execute_command chown $MAEUSER $INSTALL_DIR/TWSCCLog.properties
fi

# ***************************************************************
echo "Change access grant to $INSTALL_DIR/bin files"

if [ -f $INSTALL_DIR/bin/batchman ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/batchman
fi
if [ -f $INSTALL_DIR/bin/caxtract ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/caxtract
fi
if [ -f $INSTALL_DIR/bin/chkstat ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/chkstat
fi
if [ -f $INSTALL_DIR/bin/compiler ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/compiler
fi
if [ -f $INSTALL_DIR/bin/composer ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/composer
fi
if [ -f $INSTALL_DIR/bin/conman ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/conman
fi
if [ -f $INSTALL_DIR/bin/cpuinfo ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/cpuinfo
fi
if [ -f $INSTALL_DIR/bin/crossref ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/crossref
fi
if [ -f $INSTALL_DIR/bin/datecalc ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/datecalc
fi
if [ -f $INSTALL_DIR/bin/dateformat ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/dateformat
fi
if [ -f $INSTALL_DIR/bin/dbexpand ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/dbexpand
fi
if [ -f $INSTALL_DIR/bin/dbinfo ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/dbinfo
fi
if [ -f $INSTALL_DIR/bin/delete ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/delete
fi
if [ -f $INSTALL_DIR/bin/dwnldr ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/dwnldr
fi
if [ -f $INSTALL_DIR/bin/dumpsec ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/dumpsec
fi
if [ -f $INSTALL_DIR/bin/evtsize ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/evtsize
fi
if [ -f $INSTALL_DIR/bin/fileaid ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/fileaid
fi
if [ -f $INSTALL_DIR/bin/jbxtract ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/jbxtract
fi
if [ -f $INSTALL_DIR/bin/jobinfo ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/jobinfo
fi
if [ -f $INSTALL_DIR/bin/JOBMAN ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/JOBMAN
fi
if [ -f $INSTALL_DIR/bin/jobman ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/jobman
fi
if [ -f $INSTALL_DIR/bin/logman ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/logman
fi
if [ -f $INSTALL_DIR/bin/maestro ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/maestro
fi
if [ -f $INSTALL_DIR/bin/magent ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/magent
fi
if [ -f $INSTALL_DIR/bin/mailman ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/mailman
fi
if [ -f $INSTALL_DIR/bin/makesec ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/makesec
fi
if [ -f $INSTALL_DIR/bin/mdemon33 ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/mdemon33
fi
if [ -f $INSTALL_DIR/bin/mdemon40 ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/mdemon40
fi
if [ -f $INSTALL_DIR/bin/mecho ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/mecho
fi
if [ -f $INSTALL_DIR/bin/muser33 ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/muser33
fi
if [ -f $INSTALL_DIR/bin/muser40 ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/muser40
fi
if [ -f $INSTALL_DIR/bin/netman ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/netman
fi
if [ -f $INSTALL_DIR/bin/netmth ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/netmth
fi
if [ -f $INSTALL_DIR/bin/openssl ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/openssl
fi
if [ -f $INSTALL_DIR/bin/parms ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/parms
fi
if [ -f $INSTALL_DIR/bin/paxtract ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/paxtract
fi
if [ -f $INSTALL_DIR/bin/prxtract ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/prxtract
fi
if [ -f $INSTALL_DIR/bin/r11xtr ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/r11xtr
fi
if [ -f $INSTALL_DIR/bin/release ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/release
fi
if [ -f $INSTALL_DIR/bin/report1 ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/report1
fi
if [ -f $INSTALL_DIR/bin/report11 ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/report11
fi
if [ -f $INSTALL_DIR/bin/report2 ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/report2
fi
if [ -f $INSTALL_DIR/bin/report3 ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/report3
fi
if [ -f $INSTALL_DIR/bin/report4a ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/report4a
fi
if [ -f $INSTALL_DIR/bin/report4b ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/report4b
fi
if [ -f $INSTALL_DIR/bin/report7 ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/report7
fi
if [ -f $INSTALL_DIR/bin/report8 ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/report8
fi
if [ -f $INSTALL_DIR/bin/reporter ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/reporter
fi
if [ -f $INSTALL_DIR/bin/rextract ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/rextract
fi
if [ -f $INSTALL_DIR/bin/router ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/router
fi
if [ -f $INSTALL_DIR/bin/schedulr ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/schedulr
fi
if [ -f $INSTALL_DIR/bin/scribner ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/scribner
fi
if [ -f $INSTALL_DIR/bin/stageman ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/stageman
fi
if [ -f $INSTALL_DIR/bin/starter ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/starter
fi
if [ -f $INSTALL_DIR/bin/submit ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/submit
fi
if [ -f $INSTALL_DIR/bin/syxtract ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/syxtract
fi
if [ -f $INSTALL_DIR/bin/writer ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/writer
fi
if [ -f $INSTALL_DIR/bin/xrxtrct ]
then
	execute_command chmod 6511 $INSTALL_DIR/bin/xrxtrct
fi

# SHELL SCRIPTS
if [ -f $INSTALL_DIR/bin/at ]
then
	execute_command chmod 555 $INSTALL_DIR/bin/at
fi
if [ -f $INSTALL_DIR/bin/reptr ]
then
	execute_command chmod 555 $INSTALL_DIR/bin/reptr
fi
if [ -f $INSTALL_DIR/bin/rep7 ]
then
	execute_command chmod 555 $INSTALL_DIR/bin/rep7
fi



# Restore old TBSM binary
# Scenario Fresh: NO
# Scenario Upgrade: YES
# Scenario Promote: YES
# Scenario Patch: YES  
  if [ -f "$INSTALL_DIR/bin/clagent" ]
  then
    echo "DEBUG TRACE copy clagent $INSTALL_DIR/Tbsm/clagent/bin/clagent $INSTALL_DIR/bin/clagent "
    execute_command cp -pR $INSTALL_DIR/Tbsm/clagent/bin/clagent $INSTALL_DIR/bin/clagent
  fi

# Restore old TBSM config file
# Scenario Fresh: NO
# Scenario Upgrade: YES
# Scenario Promote: YES
# Scenario Patch: YES  
  if [ -f "$INSTALL_DIR/Tbsm/TbsmAdapter/adapter.config.bck" ]
  then
    echo "DEBUG TRACE copy clagent $INSTALL_DIR/Tbsm/TbsmAdapter/adapter.config.bck "
    execute_command cp -p $INSTALL_DIR/Tbsm/TbsmAdapter/adapter.config.bck $INSTALL_DIR/Tbsm/TbsmAdapter/adapter.config
  fi


# Copy old mozart database
# Scenario Fresh: NO
# Scenario Upgrade: YES
# Scenario Promote: NO
# Scenario Patch: NO
if [ -f "$STATUSDIR/FLOW_UPGRADE.historyFile" ]
then
  echo "DEBUG TRACE upgrade scenario"
  
  # Copy old mozart database
  if [ -d "$INSTALL_DIR/../unison/network" ]
  then
    echo "DEBUG TRACE exist $INSTALL_DIR/../unison/network"  
    if [ ! -f "$INSTALL_DIR/network/cpudata" ]
    then
      echo "DEBUG TRACE not exist $INSTALL_DIR/network/cpudata"  
      if [ -f "$INSTALL_DIR/../unison/network/cpudata" ]
      then
        echo "DEBUG TRACE copy $INSTALL_DIR/../unison/network"  
        execute_command cp -p $INSTALL_DIR/../unison/network/* $INSTALL_DIR/network
      fi
    fi
  fi

# End UPGRADE block
fi



if [ "$CREATELINKS_OPT" = "true" ]
then
  echo "Creating links..."

#  case $OS in
#   AIX)  IS_SYMLINK="-L"
#         ;;
#     *)  IS_SYMLINK="-h"
#         ;;
#  esac

  CreateLinks maestro maestro
  CreateLinks at mat
  CreateLinks batch mbatch
  CreateLinks datecalc datecalc
  CreateLinks morestdl morestdl
  CreateLinks jobstdl jobstdl
  CreateLinks parms parms
fi


echo "Updating Configuration files..."

if [ "$TWS_CPUTYPE" = "MDM" ]
then
  echo "changing names..."

  if [ -f "$STATUSDIR/FLOW_PROMOTE.historyFile" ]
  then
    TWS_MASTER=$TWS_THISCPU
  fi
  if [ -f "$STATUSDIR/FLOW_FRESH.historyFile" ]
  then
    TWS_THISCPU="$TWS_MASTER"
  fi
  
  echo "TWS_MASTER=$TWS_MASTER"
  echo "TWS_THISCPU=$TWS_THISCPU"

fi


# INSTALL: ISTANCE UPDATE CONFIG FILES ACTION (NEED UNDO)
# Scenario Fresh: YES
# Scenario Upgrade: YES
# Scenario Promote: YES
# Scenario Patch: NO
  if [ ! -f "$STATUSDIR/FLOW_PATCH.historyFile" ]
  then
    execute_command "$ACTIONTOOLS_DIR/TWSupdate_file -updateProperty $INSTALL_DIR/mozart/globalopts master $TWS_MASTER $VERBOSE"
    execute_command "$ACTIONTOOLS_DIR/TWSupdate_file -updateProperty $INSTALL_DIR/localopts thiscpu $TWS_THISCPU $VERBOSE"
  fi

# Updating localopts globalopts with new keys
# Scenario Fresh: NO
# Scenario Upgrade: YES
# Scenario Promote: NO
# Scenario Patch: NO
  if [ -f "$STATUSDIR/FLOW_UPGRADE.historyFile" ]
  then   
  #Add a simple row to avoid end of files problems
  $ACTIONTOOLS_DIR/TWSupdate_file "-addRow" "$INSTALL_DIR/localopts" "" $VERBOSE
  $ACTIONTOOLS_DIR/TWSupdate_file "-addRow" "$INSTALL_DIR/mozart/globalopts" "" $VERBOSE

  $ACTIONTOOLS_DIR/TWSupdate_file "-addRow" "$INSTALL_DIR/localopts" "nm SSL port" "0" $VERBOSE
  $ACTIONTOOLS_DIR/TWSupdate_file "-addRow" "$INSTALL_DIR/localopts" "SSL key"         "$INSTALL_DIR/ssl/TWS.key" $VERBOSE
  $ACTIONTOOLS_DIR/TWSupdate_file "-addRow" "$INSTALL_DIR/localopts" "SSL certificate" "$INSTALL_DIR/ssl/TWS.crt" $VERBOSE
  $ACTIONTOOLS_DIR/TWSupdate_file "-addRow" "$INSTALL_DIR/localopts" "SSL key pwd" "$INSTALL_DIR/ssl/TWS.sth" $VERBOSE
  $ACTIONTOOLS_DIR/TWSupdate_file "-addRow" "$INSTALL_DIR/localopts" "SSL CA certificate"  "$INSTALL_DIR/ssl/TWSTrustedCA.crt" $VERBOSE
  $ACTIONTOOLS_DIR/TWSupdate_file "-addRow" "$INSTALL_DIR/localopts" "SSL certificate chain" "$INSTALL_DIR/ssl/TWSCertificateChain.crt" $VERBOSE
  $ACTIONTOOLS_DIR/TWSupdate_file "-addRow" "$INSTALL_DIR/localopts" "SSL random seed" "$INSTALL_DIR/ssl/TWS.rnd" $VERBOSE
  $ACTIONTOOLS_DIR/TWSupdate_file "-addRow" "$INSTALL_DIR/localopts" "SSL Encryption Cipher" " SSLv3" $VERBOSE
  $ACTIONTOOLS_DIR/TWSupdate_file "-addRow" "$INSTALL_DIR/localopts" "SSL auth mode" " caonly" $VERBOSE
  $ACTIONTOOLS_DIR/TWSupdate_file "-addRow" "$INSTALL_DIR/localopts" "SSL auth string" " tws" $VERBOSE

  $ACTIONTOOLS_DIR/TWSupdate_file "-addRow" "$INSTALL_DIR/mozart/globalopts" "centralized security" " no" $VERBOSE
  $ACTIONTOOLS_DIR/TWSupdate_file "-addRow" "$INSTALL_DIR/mozart/globalopts" "enable list security check" " no" $VERBOSE
  $ACTIONTOOLS_DIR/TWSupdate_file "-addRow" "$INSTALL_DIR/mozart/globalopts" "enable switch fault tolerance" " no" $VERBOSE
  fi

# The permissions on these files after TWSupdate_file because it creates a copy of the file loosing permissions
if [ -f $INSTALL_DIR/localopts ]
then
  execute_command chown $MAEUSER $INSTALL_DIR/localopts
  execute_command chgrp $MAEGROUP $INSTALL_DIR/localopts
fi
if [ -f $INSTALL_DIR/mozart/globalopts ]
then
  execute_command chown $MAEUSER $INSTALL_DIR/mozart/globalopts
  execute_command chgrp $MAEGROUP $INSTALL_DIR/mozart/globalopts
fi

exit 0

